[llvm-commits] [llvm] r56953 - /llvm/trunk/include/llvm/Support/IRBuilder.h

Daniel Dunbar daniel at zuster.org
Thu Oct 2 10:05:05 PDT 2008


Author: ddunbar
Date: Thu Oct  2 12:05:03 2008
New Revision: 56953

URL: http://llvm.org/viewvc/llvm-project?rev=56953&view=rev
Log:
Rename IRBuilder::IsNonNull -> IsNotNull in response to feedback.

Modified:
    llvm/trunk/include/llvm/Support/IRBuilder.h

Modified: llvm/trunk/include/llvm/Support/IRBuilder.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Support/IRBuilder.h?rev=56953&r1=56952&r2=56953&view=diff

==============================================================================
--- llvm/trunk/include/llvm/Support/IRBuilder.h (original)
+++ llvm/trunk/include/llvm/Support/IRBuilder.h Thu Oct  2 12:05:03 2008
@@ -641,8 +641,8 @@
                         Name);
   }
 
-  /// CreateIsNonNull - Return an i1 value testing if \arg Arg is not null.
-  Value *CreateIsNonNull(Value *Arg, const char *Name = "") {
+  /// CreateIsNotNull - Return an i1 value testing if \arg Arg is not null.
+  Value *CreateIsNotNull(Value *Arg, const char *Name = "") {
     return CreateICmpNE(Arg, llvm::Constant::getNullValue(Arg->getType()), 
                         Name);
   }





More information about the llvm-commits mailing list